@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
 
-    http://www.imagemagick.org/script/license.php
+    https://imagemagick.org/script/license.php
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -92,15 +92,20 @@ extern WandExport MagickBooleanType
   MagickAutoGammaImage(MagickWand *),
   MagickAutoLevelImage(MagickWand *),
   MagickAutoOrientImage(MagickWand *),
+  MagickAutoThresholdImage(MagickWand *,const AutoThresholdMethod),
   MagickBlackThresholdImage(MagickWand *,const PixelWand *),
   MagickBlueShiftImage(MagickWand *,const double),
   MagickBlurImage(MagickWand *,const double,const double),
   MagickBorderImage(MagickWand *,const PixelWand *,const size_t,const size_t,
     const CompositeOperator compose),
   MagickBrightnessContrastImage(MagickWand *,const double,const double),
+  MagickCannyEdgeImage(MagickWand *,const double,const double,const double,
+    const double),
   MagickCharcoalImage(MagickWand *,const double,const double),
   MagickChopImage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t),
+  MagickCLAHEImage(MagickWand *,const size_t,const size_t,const double,
+    const double),
   MagickClampImage(MagickWand *),
   MagickClipImage(MagickWand *),
   MagickClipImagePath(MagickWand *,const char *,const MagickBooleanType),
@@ -108,13 +113,15 @@ extern WandExport MagickBooleanType
   MagickColorDecisionListImage(MagickWand *,const char *),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickColorMatrixImage(MagickWand *,const KernelInfo *),
+  MagickColorThresholdImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
     const MagickBooleanType,const ssize_t,const ssize_t),
-  MagickCompositeImageGravity(MagickWand *,const MagickWand *,const CompositeOperator,
-    const GravityType),
+  MagickCompositeImageGravity(MagickWand *,const MagickWand *,
+    const CompositeOperator,const GravityType),
   MagickCompositeLayers(MagickWand *,const MagickWand *,const CompositeOperator,
     const ssize_t,const ssize_t),
+  MagickConnectedComponentsImage(MagickWand *,const size_t,CCObjectInfo **),
   MagickConstituteImage(MagickWand *,const size_t,const size_t,const char *,
     const StorageType,const void *),
   MagickContrastImage(MagickWand *,const MagickBooleanType),
@@ -153,7 +160,6 @@ extern WandExport MagickBooleanType
   MagickGammaImage(MagickWand *,const double),
   MagickGaussianBlurImage(MagickWand *,const double,const double),
   MagickGetImageAlphaChannel(MagickWand *),
-  MagickGetImageAlphaColor(MagickWand *,PixelWand *),
   MagickGetImageBackgroundColor(MagickWand *,PixelWand *),
   MagickGetImageBluePrimary(MagickWand *,double *,double *,double *),
   MagickGetImageBorderColor(MagickWand *,PixelWand *),
@@ -165,6 +171,7 @@ extern WandExport MagickBooleanType
     double *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *,double *),
   MagickGetImageLength(MagickWand *,MagickSizeType *),
+  MagickGetImageMatteColor(MagickWand *,PixelWand *),
   MagickGetImagePage(MagickWand *,size_t *,size_t *,ssize_t *,
     ssize_t *),
   MagickGetImagePixelColor(MagickWand *,const ssize_t,const ssize_t,
@@ -176,6 +183,7 @@ extern WandExport MagickBooleanType
   MagickHaldClutImage(MagickWand *,const MagickWand *),
   MagickHasNextImage(MagickWand *),
   MagickHasPreviousImage(MagickWand *),
+  MagickHoughLineImage(MagickWand *,const size_t,const size_t,const size_t),
   MagickImplodeImage(MagickWand *,const double,const PixelInterpolateMethod),
   MagickImportImagePixels(MagickWand *,const ssize_t,const ssize_t,const size_t,
     const size_t,const char *,const StorageType,const void *),
@@ -183,19 +191,24 @@ extern WandExport MagickBooleanType
     const PixelInterpolateMethod),
   MagickInverseFourierTransformImage(MagickWand *,MagickWand *,
     const MagickBooleanType),
+  MagickKuwaharaImage(MagickWand *,const double,const double),
   MagickLabelImage(MagickWand *,const char *),
   MagickLevelImage(MagickWand *,const double,const double,const double),
+  MagickLevelImageColors(MagickWand *,const PixelWand *,const PixelWand *,
+    const MagickBooleanType),
+  MagickLevelizeImage(MagickWand *,const double,const double,const double),
   MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickLiquidRescaleImage(MagickWand *,const size_t,const size_t,const double,
     const double),
   MagickLocalContrastImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
+  MagickMeanShiftImage(MagickWand *,const size_t,const size_t,const double),
   MagickMedianConvolveImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
   MagickModeImage(MagickWand *,const double),
   MagickModulateImage(MagickWand *,const double,const double,const double),
-  MagickMorphologyImage(MagickWand *,MorphologyMethod,const ssize_t,
-    KernelInfo *),
+  MagickMorphologyImage(MagickWand *,const MorphologyMethod,const ssize_t,
+    const KernelInfo *),
   MagickMotionBlurImage(MagickWand *,const double,const double,const double),
   MagickNegateImage(MagickWand *,const MagickBooleanType),
   MagickNewImage(MagickWand *,const size_t,const size_t,const PixelWand *),
@@ -206,6 +219,7 @@ extern WandExport MagickBooleanType
     const double,const MagickBooleanType),
   MagickOptimizeImageTransparency(MagickWand *),
   MagickOrderedDitherImage(MagickWand *,const char *),
+  MagickPolynomialImage(MagickWand *,const size_t,const double *),
   MagickTransparentPaintImage(MagickWand *,const PixelWand *,
     const double,const double,const MagickBooleanType invert),
   MagickPingImage(MagickWand *,const char *),
@@ -219,6 +233,8 @@ extern WandExport MagickBooleanType
     const size_t,const DitherMethod,const MagickBooleanType),
   MagickQuantizeImages(MagickWand *,const size_t,const ColorspaceType,
     const size_t,const DitherMethod,const MagickBooleanType),
+  MagickRangeThresholdImage(MagickWand *,const double,const double,
+    const double,const double),
   MagickRotationalBlurImage(MagickWand *,const double),
   MagickRaiseImage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t,const MagickBooleanType),
@@ -245,7 +261,6 @@ extern WandExport MagickBooleanType
   MagickSetImage(MagickWand *,const MagickWand *),
   MagickSetImageAlpha(MagickWand *,const double),
   MagickSetImageAlphaChannel(MagickWand *,const AlphaChannelOption),
-  MagickSetImageAlphaColor(MagickWand *,const PixelWand *),
   MagickSetImageBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetImageBluePrimary(MagickWand *,const double,const double,
     const double),
@@ -273,9 +288,12 @@ extern WandExport MagickBooleanType
   MagickSetImageInterpolateMethod(MagickWand *,const PixelInterpolateMethod),
   MagickSetImageIterations(MagickWand *,const size_t),
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
+  MagickSetImageMatteColor(MagickWand *,const PixelWand *),
   MagickSetImageOrientation(MagickWand *,const OrientationType),
   MagickSetImagePage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t),
+  MagickSetImagePixelColor(MagickWand *,const ssize_t,const ssize_t,
+    const PixelWand *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double,
     const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
@@ -321,6 +339,7 @@ extern WandExport MagickBooleanType
     const ssize_t),
   MagickWaveImage(MagickWand *,const double,const double,
     const PixelInterpolateMethod),
+  MagickWaveletDenoiseImage(MagickWand *,const double,const double),
   MagickWhiteThresholdImage(MagickWand *,const PixelWand *),
   MagickWriteImage(MagickWand *,const char *),
   MagickWriteImageFile(MagickWand *,FILE *),
@@ -339,6 +358,7 @@ extern WandExport MagickWand
   *MagickCompareImages(MagickWand *,const MagickWand *,const MetricType,
     double *),
   *MagickCompareImagesLayers(MagickWand *,const LayerMethod),
+  *MagickComplexImages(MagickWand *,const ComplexOperator),
   *MagickDeconstructImages(MagickWand *),
   *MagickEvaluateImages(MagickWand *,const MagickEvaluateOperator),
   *MagickFxImage(MagickWand *,const char *),
